<?php

namespace Luticate\Auth\Business;

use Luticate\Utils\LuBusiness;
use Luticate\Auth\DataAccess\LuticatePermissionsDataAccess;
use Luticate\Auth\DBO\LuticatePermissionsDbo;

class LuticatePermissionsBusiness extends LuBusiness {
    protected static function getDataAccess()
    {
        return new LuticatePermissionsDataAccess();
    }

    public static function checkPermissionName($permission_name)
    {
        $perm = LuticatePermissionsDataAccess::getByName($permission_name);
        if (is_null($perm)) {
            self::notFound("Permission not found");
        }
        return $perm;
    }

    public static function getUserPermission($user_id, $permission_name, $default = false)
    {
        $val = LuticatePermissionsDataAccess::getUserPermission($user_id, $permission_name);
        if (is_null($val)) {
            return $default;
        }
        return $val;
    }

    public static function getUserDynamicPermission($user_id, $permission_name, $action, $resource_id, $default = false)
    {
        $dynamic_permission_name = "LU_DYN_" . $permission_name . "_" . $action . "_" . $resource_id;
        $val = LuticatePermissionsDataAccess::getUserPermission($user_id, $dynamic_permission_name);
        if (is_null($val)) {
            return self::getUserPermission($user_id, $permission_name, $default);
        }
        return $val;
    }

    public static function add($permission_name, $permission_value)
    {
        $perm = LuticatePermissionsDataAccess::getByName($permission_name);
        if (is_null($perm)) {
            $perm = new LuticatePermissionsDbo();
            $perm->setName($permission_name);
            $perm->setValue($permission_value);
            LuticatePermissionsDataAccess::add($perm);
            return true;
        }
        self::badInput("Permission name already exists");
        return false;
    }

    public static function del($permission_name)
    {
        LuticatePermissionsDataAccess::delete($permission_name);
        return true;
    }

    public static function edit($permission_name, $permission_value)
    {
        self::checkPermissionName($permission_name);
        LuticatePermissionsDataAccess::edit($permission_name, $permission_value);
        return true;
    }
}